package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.Dangan;

import java.util.List;

/**
 * 档案管理Mapper接口
 * 
 * @author ruoyi
 * @date 2022-10-20
 */
public interface DanganMapper 
{
    /**
     * 查询档案管理
     * 
     * @param fileId 档案管理ID
     * @return 档案管理
     */
    public Dangan selectDanganById(Long fileId);

    //根据档案编号获取档案信息
    Dangan  selectDanganByDanganName(String danganName);
    /**
     * 查询档案管理列表
     * 
     * @param dangan 档案管理
     * @return 档案管理集合
     */
    public List<Dangan> selectDanganList(Dangan dangan);

    /**
     * 新增档案管理
     * 
     * @param dangan 档案管理
     * @return 结果
     */
    public int insertDangan(Dangan dangan);

    /**
     * 修改档案管理
     * 
     * @param dangan 档案管理
     * @return 结果
     */
    public int updateDangan(Dangan dangan);

    /**
     * 删除档案管理
     * 
     * @param danganId 档案管理ID
     * @return 结果
     */
    public int deleteDanganById(Long danganId);

    /**
     * 批量删除档案管理
     * 
     * @param danganIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteDanganByIds(String[] danganIds);

    /**
     * 校验名称是否唯一
     *
     * @param loginName 档案名称
     * @return 结果
     */
    public int checkDanganNameUnique(String loginName);



}
